pub mod api;
#[macro_use] pub mod error;

pub use api::ApiResponse;
pub use api::ApiResponseErr;
